function SingleTraceExample(Irradiation)
% This function produces an example trace for a single cell and also
% locates the peaks in recA activity. The irradiation can be chosen as the
% functional argument, units are simply J/m^2 as in the paper.

Damage = Irradiation.*0.11;

%Mean delay time tau dependent on irradiation level
FriedmanTau = 68; %From Friedman et al. paper

%Linear Fit
TDNull = 34.8; TDPrime = 1.3; %From regression to Friedman et al. data, Rsquare = 0.9481
TD = TDNull+TDPrime.*Irradiation;

%2nd degree polynomial fit
%From regression to Friedman et al. data, Rsquare=0.9702
TDNull = 39.0; TDPrime = 0.599; TDPrimePrime = 0.0135;
TD = TDPrimePrime.*Irradiation.^2 + TDPrime.*Irradiation + TDNull;

%Mean tau from Friedman et al. paper relation
MeanTau = FriedmanTau./4.35.*TD./(FriedmanTau+TD);

ElapsedTime = 150;
NumberOfCells = 51;
global sNull lagtime

kk=1;
NumberOfCells = 1;

TOneContainer = zeros(2,NumberOfCells);
TTwoContainer = TOneContainer;
TThreeContainer = TOneContainer;

for kk = 1:NumberOfCells;
    NumberOfCells-kk+1
    
    tau = MeanTau.*(1+random('norm',0,0.03)); %Delay in minutes
    sNull = 0.37.*(1+random('norm',0,0.2));
    lagtime = 3.*tau;%18.5.*(1+random('norm',0,0.16));
    
    lags = [tau]; % Delay times
    tspan = [0,ElapsedTime]; %Timespan for the simulation
    StartE = 0;
    DNull = Damage.*(1+random('norm',0,0.05));
    history = [StartE;DNull;0]; %Constant value that is used for the history needed for the delay type problem
    
    options = ddeset('MaxStep',50);
    sol = ddesd(@ddefunction,lags,history,tspan,options); %Invocation of the DDE integrator
    
    [pks,locs] = findpeaks(-sol.yp(2,:));
    pks = pks./max(pks);
    
    plot(sol.x,-sol.yp(2,:)./max(-sol.yp(2,:)),'r-',...
        sol.x,sol.y(2,:)./DNull,'k-')
    hold on
    xlabel('Time after UV irradiation (min)')
    ylabel('D(t) and -dD/dt(t) (normalized)')
    
    if ~isempty(pks)
        TOneContainer(1) = pks(1);
        TOneContainer(2) = sol.x(locs(1));
        plot(TOneContainer(2),TOneContainer(1),'ro')
    end
    if length(pks)>1
        TTwoContainer(1) = pks(2);
        TTwoContainer(2) = sol.x(locs(2));
        plot(TTwoContainer(2),TTwoContainer(1),'go');
    end
    if length(pks)>2
        TThreeContainer(1) = pks(3);
        TThreeContainer(2) = sol.x(locs(3));
        plot(TThreeContainer(2),TThreeContainer(1),'bo');
    end
    hold off
        
end




%Defining the subroutine, that is used as the DDEs in the integrator dde23
function vv = ddefunction(tt,yy,ZZ)

global sNull lagtime

gamma = 0.1;
nn = 1;
nnd = 3;
CC = 0.1;

vv = zeros(3,1);

%Actual DDE, yy is xx, ZZ(1) is xx delayed by tau
vv(1) = max(yy(2).^nnd./(1+yy(2).^nnd),0).*(gamma.*heaviside(tt-lagtime) - sNull.*((ZZ(1)).^nn)./(1+(ZZ(1)).^nn));
vv(2) = -CC.*max(yy(2)./(1+yy(2)),0).*max(((yy(1)).^nn)./(1+(yy(1)).^nn),0);
vv(3) = ((yy(1)).^nn)./(1+(yy(1)).^nn);